@@ -164,3 +164,8 @@ if (Froxlor::isFroxlorVersion('2.2.0-rc3')) {
 	Update::showUpdateStep("Updating from 2.2.0-rc3 to 2.2.0 stable", false);
 	Froxlor::updateToVersion('2.2.0');
 }
+
+if (Froxlor::isFroxlorVersion('2.2.0')) {
+	Update::showUpdateStep("Updating from 2.2.0 to 2.2.1", false);
+	Froxlor::updateToVersion('2.2.1');
+}
