@@ -33,6 +33,7 @@ use Froxlor\Api\Commands\SubDomains;
 use Froxlor\Database\Database;
 use Froxlor\PhpHelper;
 use Froxlor\UI\Panel\UI;
+use Froxlor\UI\Request;
 use Froxlor\UI\Response;
 
 // This file is being included in admin_domains and customer_domains
@@ -49,13 +50,17 @@ if ($action == '' || $action == 'view') {
 	}
 	$result_domain = json_decode($json_result, true)['data'];
 
-	if (isset($_POST['send']) && $_POST['send'] == 'send') {
-		$do_insert = isset($_POST['do_insert']) && ((($_POST['do_insert'] == 1) ? true : false));
+	if ($result_domain['email_only']) {
+		Response::dynamicError("There are no ssl-certificates for email only domains.");
+	}
+
+	if (Request::post('send') == 'send') {
+		$do_insert = Request::post('do_insert', 0) == 1;
 		try {
 			if ($do_insert) {
-				Certificates::getLocal($userinfo, $_POST)->add();
+				Certificates::getLocal($userinfo, Request::postAll())->add();
 			} else {
-				Certificates::getLocal($userinfo, $_POST)->update();
+				Certificates::getLocal($userinfo, Request::postAll())->update();
 			}
 		} catch (Exception $e) {
 			Response::dynamicError($e->getMessage());
